@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: chain.c 135 2004-11-22 00:55:56Z pdh $
+ * $Id: chain.c 157 2005-02-19 17:57:59Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -104,6 +104,8 @@ static const char *memory_config(size_t *bank)
 	static char buf[16];
 	char *ptr;
 
+#if 0
+
 	ptr = to_decimal(buf, bank[0] >> 20);
 	*ptr++ = ',';
 	ptr = to_decimal(ptr, bank[1] >> 20);
@@ -112,6 +114,20 @@ static const char *memory_config(size_t *bank)
 	ptr = to_decimal(ptr, (bank[0] + bank[1]) >> 20);
 	*ptr = '\0';
 
+#else
+
+	unsigned idx;
+	char chr;
+
+	ptr = to_decimal(buf, (bank[0] + bank[1]) >> 20);
+	idx = 0;
+	do {
+		chr = "MB RAM"[idx];
+		ptr[idx++] = chr;
+	} while(chr);
+
+#endif
+
 	return buf;
 }
 
