@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: galileo.h 135 2004-11-22 00:55:56Z pdh $
+ * $Id: galileo.h 175 2005-03-31 20:50:43Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -57,6 +57,8 @@
 #define BRDG_REG_TIMEOUT_RETRY			0xc04
 #define BRDG_REG_RAS01_BANK_SIZE			0xc08
 #define BRDG_REG_RAS23_BANK_SIZE			0xc0c
+#define BRDG_REG_INTR_CAUSE				0xc18
+# define BRDG_INTR_CAUSE_RETRY_CTR		(1 << 20)
 
 #endif
 
