@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: main.c 174 2005-03-31 20:14:59Z pdh $
+ * $Id: main.c 184 2006-01-16 23:43:15Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -69,6 +69,11 @@ void loader(size_t bank0, size_t bank1, unsigned switches)
 
 		lcd_line(0, "!  UNIT BOOT   !");
 		lcd_line(1, "!   FAILED     !");
+
+	} else {
+
+		lcd_line(0, "Boot shell...");
+		lcd_line(1, NULL);
 	}
 
 	if(!netcon_enabled())
