@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: nfs.c 79 2004-05-23 12:14:25Z pdh $
+ * $Id: nfs.c 183 2006-01-16 23:32:21Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -604,7 +604,7 @@ invalid:
 					memcpy(scratch.b, data + 3 * 4, nmsz);
 					scratch.b[nmsz] = '\0';
 
-					code = func(arg, scratch.b, &obj);
+					code = func(arg, (char *) scratch.b, &obj);
 					if(code)
 						return code;
 				}
@@ -735,7 +735,7 @@ static int dump_node(void *arg, const char *name, struct nfs_object *obj)
 	putstring_safe(name, -1);
 
 	if(S_ISLNK(mode)) {
-		if(size <= sizeof(scratch) && nfs_readlink((int) arg, scratch.b, obj)) {
+		if(size <= sizeof(scratch) && nfs_readlink((int) arg, (char *) scratch.b, obj)) {
 			putstring(" --> ");
 			putstring_safe(scratch.b, size);
 		} else
