@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: nv.c 154 2004-12-16 21:10:34Z pdh $
+ * $Id: nv.c 183 2006-01-16 23:32:21Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  */
@@ -117,6 +117,13 @@ void nv_get(int clear)
 		nv_store.vers = 2;
 	}
 
+	if(nv_store.vers < 3) {
+
+		nv_store.keymap = 0;
+
+		nv_store.vers = 3;
+	}
+
 	nv_put();
 }
 
