@@ -1,7 +1,7 @@
 /*
  * (C) P.Horton 2004
  *
- * $Id: serial.c 137 2004-11-27 00:26:09Z pdh $
+ * $Id: serial.c 166 2005-03-22 20:55:41Z pdh $
  *
  * This code is covered by the GNU General Public License. For details see the file "COPYING".
  *
@@ -74,7 +74,7 @@ static const unsigned rates[] =
 };
 
 static unsigned queue_in, queue_out;
-static char out_queue[1024];
+static char out_queue[2048];
 static unsigned baud;
 static enum { ST_UNINIT = 0, ST_DISABLED, ST_ENABLED } state;
 static volatile uint8_t *uart_base;
@@ -88,8 +88,36 @@ static unsigned stored_baud(void)
 	return rates[nv_store.baud - 1];
 }
 
+static unsigned flush_netcon(void)
+{
+	unsigned indx, copy, fill;
+
+	for(copy = queue_out;;) {
+
+		fill = queue_in - copy;
+		if(!fill)
+			break;
+
+		indx = copy % sizeof(out_queue);
+		if(indx + fill > sizeof(out_queue))
+			fill = sizeof(out_queue) - indx;
+
+		fill = netcon_write(out_queue + indx, fill);
+		if(!fill)
+			break;
+
+		copy += fill;
+	}
+
+	return copy - queue_out;
+}
+
 static void flush_ring(void)
 {
+	unsigned copy;
+
+	copy = flush_netcon();
+
 	if(state == ST_ENABLED)
 
 		while(queue_in != queue_out) {
@@ -99,6 +127,10 @@ static void flush_ring(void)
 
 			UART_THR = out_queue[queue_out++ % sizeof(out_queue)];
 		}
+
+	else
+
+		queue_out += copy;
 }
 
 void serial_enable(int enable)
@@ -121,10 +153,9 @@ void serial_enable(int enable)
 		uart_base = UART_REGISTER;
 		uart_clock = UART_CLOCK;
 
-#ifdef PCI_SERIAL
-
-		if(pcicfg_read_word(PCI_DEV_SLOT, PCI_FNC_SLOT, 0x00) == ((TIMEDIA_DEV_ID << 16) | TIMEDIA_VND_ID)) {
-
+		if((nv_store.flags & NVFLAG_CONSOLE_PCI_SERIAL) &&
+			pcicfg_read_word(PCI_DEV_SLOT, PCI_FNC_SLOT, 0x00) == ((TIMEDIA_DEV_ID << 16) | TIMEDIA_VND_ID))
+		{
 			pcicfg_write_word(PCI_DEV_SLOT, PCI_FNC_SLOT, 0x10, TIMEDIA_BASE);
 
 			pcicfg_write_half(PCI_DEV_SLOT, PCI_FNC_SLOT, 0x04,
@@ -134,8 +165,6 @@ void serial_enable(int enable)
 			uart_clock = TIMEDIA_CLOCK;
 		}
 
-#endif
-
 		baud = stored_baud();
 		div = (uart_clock + baud * 8) / (baud * 16);
 
@@ -162,8 +191,6 @@ void drain(void)
 			yield();
 }
 
-#ifdef PCI_SERIAL
-
 /*
  * don't hog the PCI bus whilst polling the serial
  */
@@ -189,16 +216,7 @@ int kbhit(void)
 		}
 	}
 
-	yield();
-
-	return 0;
-}
-
-#else
-
-int kbhit(void)
-{
-	if(state == ST_ENABLED && (UART_LSR & UART_LSR_RDR))
+	if(netcon_poll())
 		return 1;
 
 	yield();
@@ -206,14 +224,20 @@ int kbhit(void)
 	return 0;
 }
 
-#endif
-
 int getch(void)
 {
+	uint8_t tmp;
+
 	while(!kbhit())
 		;
 
-	return UART_RHR;
+	if(state == ST_ENABLED && (UART_LSR & UART_LSR_RDR))
+		return UART_RHR;
+
+	if(netcon_read(&tmp, 1))
+		return tmp;
+
+	return 0;
 }
 
 void putchar(int chr)
